<?php

/**
 * @file
 * Contains \Drupal\custom_pub\Entity\CustomPublishingOption.
 */

namespace Drupal\custom_pub\Entity;

use Drupal\Core\Config\Entity\ConfigEntityBase;
use Drupal\Core\Entity\EntityManagerInterface;
use Drupal\Core\Entity\EntityTypeInterface;
use Drupal\custom_pub\CustomPublishingOptionInterface;
use Drupal\Core\Entity\EntityStorageInterface;
use Drupal\Core\Field\BaseFieldDefinition;

/**
 * Defines the Custom publishing option entity.
 *
 * @ConfigEntityType(
 *   id = "custom_publishing_option",
 *   label = @Translation("Custom publishing option"),
 *   handlers = {
 *     "list_builder" = "Drupal\custom_pub\CustomPublishingOptionListBuilder",
 *     "form" = {
 *       "add" = "Drupal\custom_pub\Form\CustomPublishingOptionForm",
 *       "edit" = "Drupal\custom_pub\Form\CustomPublishingOptionForm",
 *       "delete" = "Drupal\custom_pub\Form\CustomPublishingOptionDeleteForm"
 *     },
 *     "route_provider" = {
 *       "html" = "Drupal\custom_pub\CustomPublishingOptionHtmlRouteProvider",
 *     },
 *   },
 *   config_prefix = "custom_publishing_option",
 *   admin_permission = "administer site configuration",
 *   entity_keys = {
 *     "id" = "id",
 *     "label" = "label",
 *     "uuid" = "uuid"
 *   },
 *   links = {
 *     "canonical" = "/admin/config/content/custom_publishing_option/{custom_publishing_option}",
 *     "add-form" = "/admin/config/content/custom_publishing_option/add",
 *     "edit-form" = "/admin/config/content/custom_publishing_option/{custom_publishing_option}/edit",
 *     "delete-form" = "/admin/config/content/custom_publishing_option/{custom_publishing_option}/delete",
 *     "collection" = "/admin/config/content/custom_publishing_option"
 *   }
 * )
 */
class CustomPublishingOption extends ConfigEntityBase implements CustomPublishingOptionInterface {

  /**
   * The Custom publishing option ID.
   *
   * @var string
   */
  protected $id;

  /**
   * The Custom publishing option label.
   *
   * @var string
   */
  protected $label;

  /**
   * {@inheritdoc}
   */
  public function postSave(EntityStorageInterface $storage, $update = TRUE) {
    parent::postSave($storage, $update);

    $manager = \Drupal::entityDefinitionUpdateManager();

    $storage_definition = BaseFieldDefinition::create('boolean')
      ->setLabel(t('!label', ['!label' => $this->label()]))
      ->setDescription(t('A boolean added by custom publishing options.'))
      ->setRevisionable(TRUE)
      ->setTranslatable(TRUE)
      ->setDefaultValue(0)
      ->setDisplayConfigurable('form', TRUE);

    $manager->installFieldStorageDefinition('cpo_' . $this->id(), 'node', 'custom_pub', $storage_definition);
  }

  /**
   * {@inheritdoc}
   */
  public static function postDelete(EntityStorageInterface $storage, array $entities) {
    parent::postDelete($storage, $entities);

    $manager = \Drupal::entityDefinitionUpdateManager();

    foreach ($entities as $id => $entity) {
      $storage_definition = $manager->getFieldStorageDefinition('cpo_' . $entity->id(), 'node');

      if (isset($storage_definition)) {
        $manager->uninstallFieldStorageDefinition($storage_definition);
      }
    }
  }
}
