<?php

/**
 * @file
 * Contains \Drupal\custom_pub\Form\CustomPublishingOptionForm.
 */

namespace Drupal\custom_pub\Form;

use Drupal\Core\Entity\EntityInterface;
use Drupal\Core\Entity\EntityForm;
use Drupal\Core\Form\FormStateInterface;

/**
 * Class CustomPublishingOptionForm.
 *
 * @package Drupal\custom_pub\Form
 */
class CustomPublishingOptionForm extends EntityForm {
  /**
   * {@inheritdoc}
   */
  public function form(array $form, FormStateInterface $form_state) {
    $form = parent::form($form, $form_state);

    $custom_publishing_option = $this->entity;
    $form['label'] = array(
      '#type' => 'textfield',
      '#title' => $this->t('Label'),
      '#maxlength' => 255,
      '#default_value' => $custom_publishing_option->label(),
      '#description' => $this->t("Label for the Custom publishing option."),
      '#required' => TRUE,
    );

    $form['id'] = array(
      '#type' => 'machine_name',
      '#default_value' => $custom_publishing_option->id(),
      '#machine_name' => array(
        'exists' => '\Drupal\custom_pub\Entity\CustomPublishingOption::load',
      ),
      '#disabled' => !$custom_publishing_option->isNew(),
    );

    /* You will need additional form elements for your custom properties. */

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function save(array $form, FormStateInterface $form_state) {
    $custom_publishing_option = $this->entity;
    $status = $custom_publishing_option->save();

    switch ($status) {
      case SAVED_NEW:
        drupal_set_message($this->t('Created the %label Custom publishing option.', [
          '%label' => $custom_publishing_option->label(),
        ]));
        break;

      default:
        drupal_set_message($this->t('Saved the %label Custom publishing option.', [
          '%label' => $custom_publishing_option->label(),
        ]));
    }
    $form_state->setRedirectUrl($custom_publishing_option->urlInfo('collection'));
  }

}
